/* AlSb.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 31 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// Parabolic Conduction Band

CB_FULL[ALSB][0]=+5.3706e+23;
CB_FULL[ALSB][1]=-2.6626e+22;
CB_FULL[ALSB][2]=+5.5766e+20;
CB_FULL[ALSB][3]=-6.4249e+18;
CB_FULL[ALSB][4]=+4.4457e+16;
CB_FULL[ALSB][5]=-1.8950e+14;
CB_FULL[ALSB][6]=+4.9115e+11;
CB_FULL[ALSB][7]=-7.3542e+08;
CB_FULL[ALSB][8]=+1.1316e+07;
CB_FULL[ALSB][9]=-1.8334e+02;
CB_FULL[ALSB][10]=0.0; //1.2999e-02;
